"""version_warning.py

Module containing custom warning classes.

"""


from __future__ import annotations


class MastapyImportWarning(ImportWarning):
    """MastapyImportWarning

    A custom warning class for mastapy import warnings.
    """
